const StellarSdk = require("stellar-sdk");
require("dotenv").config();
const server = new StellarSdk.Server(process.env.STELLARTESTNET);

async function DoManageData(sourceSeed, assetCode, ipfsHash) {
  try {
    // Load source account details
    const sourceKeypair = StellarSdk.Keypair.fromSecret(sourceSeed);
    const account = await server.loadAccount(sourceKeypair.publicKey());

    // Create a manage data operation with assetCode as name and ipfsHash as value
    const operation = StellarSdk.Operation.manageData({
      name: assetCode,
      value: ipfsHash,
    });

    // Build the transaction
    const transaction = new StellarSdk.TransactionBuilder(account, {
      fee: StellarSdk.BASE_FEE,
      networkPassphrase: StellarSdk.Networks.TESTNET,
    })
      .addOperation(operation)
      .setTimeout(30)
      .build();

    // Sign the transaction with the source account keypair
    transaction.sign(sourceKeypair);

    // Submit the transaction to the Stellar network
    const transactionResult = await server.submitTransaction(transaction);

    // Log the transaction hash
    console.log(
      `Transaction hash for NFT issuer manage data : ${transactionResult.hash}`
    );

    return true;
  } catch (error) {
    console.error("Error when submitting NFT manage data", error);
    return false;
  }
}
module.exports = DoManageData;
