import React, { useState } from "react";
import { View, Text, Button, StyleSheet, Alert, Clipboard } from "react-native";
import RadioForm, {
  RadioButton,
  RadioButtonInput,
  RadioButtonLabel,
} from "react-native-simple-radio-button";
import EncryptWithServerKey from "../../../services/encryptByServerKey";
import { LOCALBACKEND } from "../../../env";
import DecryptWithServerKey from "../../../services/decryptByServerKey";
import AsyncStorage from "@react-native-async-storage/async-storage";
import Clipboard from "@react-native-clipboard/clipboard";

export default function PatientRegEight({ navigation, route }) {
  const [educationLevel, setEducationLevel] = useState("");
  const [employedStatus, setEmployedStatus] = useState("");

  const educationLevelOptions = [
    { label: "Schooling", value: "Schooling" },
    { label: "School Leaver", value: "School leaver" },
    { label: "Undergraduate", value: "Undergraduate" },
    { label: "Post Graduate", value: "Post graduate" },
  ];

  const employedOptions = [
    { label: "Yes", value: "Yes" },
    { label: "No", value: "No" },
    { label: "Self Employed", value: "Self Employed" },
  ];

  const handleSave = async () => {
    //encrypt the data
    const encryptedEmail = EncryptWithServerKey(route.params.email);
    const encryptedUsername = EncryptWithServerKey(route.params.username);
    const encryptedPassword = EncryptWithServerKey(route.params.password);
    const encryptedName = EncryptWithServerKey(route.params.name);
    const encryptedPronoun = EncryptWithServerKey(route.params.pronoun);
    const encryptedStringDate = EncryptWithServerKey(route.params.stringDate);
    const encryptedGender = EncryptWithServerKey(route.params.gender);
    const encryptedOrphan = EncryptWithServerKey(route.params.orphan);
    const encryptedSiblingCount = EncryptWithServerKey(
      route.params.siblingCount
    );
    const encryptedRelationshipStatus = EncryptWithServerKey(
      route.params.relationshipStatus
    );
    const encryptedNumberOfChildren = EncryptWithServerKey(
      route.params.numberOfChildren
    );
    const encryptedSexualPreference = EncryptWithServerKey(
      route.params.sexualPreference
    );
    const encryptedEthnicity = EncryptWithServerKey(route.params.ethnicity);
    const encryptedReligion = EncryptWithServerKey(route.params.religion);
    const encryptedNationality = EncryptWithServerKey(route.params.nationality);
    const encryptedEducationLevel = EncryptWithServerKey(educationLevel);
    const encryptedEmployedStatus = EncryptWithServerKey(employedStatus);
    //create JSON object
    const regObject = {
      email: encryptedEmail,
      username: encryptedUsername,
      password: encryptedPassword,
      name: encryptedName,
      pronoun: encryptedPronoun,
      birthday: encryptedStringDate,
      gender: encryptedGender,
      orphan: encryptedOrphan,
      siblingcount: encryptedSiblingCount,
      relationship: encryptedRelationshipStatus,
      childcount: encryptedNumberOfChildren,
      sexualpreference: encryptedSexualPreference,
      religion: encryptedReligion,
      ethnicity: encryptedEthnicity,
      nationality: encryptedNationality,
      educationlevel: encryptedEducationLevel,
      employed: encryptedEmployedStatus,
    };

    console.log("999999999999999999999", regObject);

    const registerUrl = LOCALBACKEND + `/patient/register`;

    //call the backend endpoint
    try {
      const regResponse = await fetch(registerUrl, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify(regObject),
      });

      console.log("9--------------------------------", regObject);

      const responseData = await regResponse.json();

      if (regResponse.ok) {
        console.log("Registration success in backend...");
        const { message, hash, pubkey, seed, rsapk, rsask } = responseData;
        //decrypt the data
        const decryptedStellarPublicKey = DecryptWithServerKey(pubkey);
        const decryptedStellarSecretKey = DecryptWithServerKey(seed);
        const decryptedRsaPublicKey = DecryptWithServerKey(rsapk);
        const decryptedRsaSecretKey = DecryptWithServerKey(rsask);

        try {
          //save in async storage
          await AsyncStorage.setItem(
            "patientStellarPublicKey",
            decryptedStellarPublicKey
          );
          await AsyncStorage.setItem(
            "patientStellarSecretKey",
            decryptedStellarSecretKey
          );
          await AsyncStorage.setItem(
            "patientRsaPublicKey",
            decryptedRsaPublicKey
          );
          await AsyncStorage.setItem(
            "patientRsaSecretKey",
            decryptedRsaSecretKey
          );

          const copyMessage =
            `Public key : ` +
            decryptedStellarPublicKey +
            `,Secret key : ` +
            decryptedStellarSecretKey;
          const alertMessage =
            `Public key : ` +
            decryptedStellarPublicKey +
            `\nSecret key : ` +
            decryptedStellarSecretKey +
            `\n Save the keys in a safe place`;

          //Show keys on the alert
          Alert.alert("Account keys", alertMessage, [
            {
              text: "Copy",
              onPress: () => {
                console.log(copyMessage);
                Clipboard.setStrings(
                  ["Public key : " + decryptedStellarPublicKey],
                  ["Secret key : " + decryptedStellarSecretKey]
                );
              },
            },
            { text: "Close", style: "cancel" },
          ]);
          //on close send to main UI
        } catch (errorWhenStoringInAsyncStorage) {
          console.log(errorWhenStoringInAsyncStorage);
        }
      } else {
        console.log(responseData);
      }
    } catch (errorWhenSendingRegObj) {
      console.error("Error : ", errorWhenSendingRegObj);
    }
  };

  return (
    <View style={styles.container}>
      <Text>Highest Education Level:</Text>
      <RadioForm animation={true}>
        {educationLevelOptions.map((option, index) => (
          <RadioButton
            labelHorizontal={true}
            key={index}
            labelWrapStyle={{ flexDirection: "row", alignItems: "center" }}
          >
            <RadioButtonInput
              obj={option}
              index={index}
              isSelected={educationLevel === option.value}
              onPress={() => setEducationLevel(option.value)}
              buttonInnerColor={"#2196f3"}
              buttonOuterColor={
                educationLevel === option.value ? "#2196f3" : "#000"
              }
              buttonSize={15}
              buttonOuterSize={25}
              buttonStyle={{}}
              buttonWrapStyle={{ marginLeft: 10 }}
            />
            <RadioButtonLabel
              obj={option}
              index={index}
              labelHorizontal={true}
              onPress={() => setEducationLevel(option.value)}
              labelStyle={{ fontSize: 16, marginRight: 10 }}
            />
          </RadioButton>
        ))}
      </RadioForm>

      <Text>Employed:</Text>
      <RadioForm animation={true}>
        {employedOptions.map((option, index) => (
          <RadioButton
            labelHorizontal={true}
            key={index}
            labelWrapStyle={{ flexDirection: "row", alignItems: "center" }}
          >
            <RadioButtonInput
              obj={option}
              index={index}
              isSelected={employedStatus === option.value}
              onPress={() => setEmployedStatus(option.value)}
              buttonInnerColor={"#2196f3"}
              buttonOuterColor={
                employedStatus === option.value ? "#2196f3" : "#000"
              }
              buttonSize={15}
              buttonOuterSize={25}
              buttonStyle={{}}
              buttonWrapStyle={{ marginLeft: 10 }}
            />
            <RadioButtonLabel
              obj={option}
              index={index}
              labelHorizontal={true}
              onPress={() => setEmployedStatus(option.value)}
              labelStyle={{ fontSize: 16, marginRight: 10 }}
            />
          </RadioButton>
        ))}
      </RadioForm>

      <Button title="All Done" onPress={handleSave} />
    </View>
  );
}
const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: "center",
    justifyContent: "center",
  },
});
